# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/savings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/inventory/v1/savings.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"C\n\x15GetPlInventoryRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x17\n\x0fpl_inventory_id\x18\x02 \x01(\t\"\x81\x02\n\x0fPlInventoryInfo\x12\x17\n\x0fpl_inventory_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x11\n\tsale_type\x18\x07 \x01(\t\x12\r\n\x05state\x18\x08 \x01(\t\x12%\n\x04\x64\x61ta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\"Q\n\x10PlInventoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"d\n\x10PlInventorysInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.inventory.v1.PlInventoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"_\n\x14PlInventoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"I\n\x19GetPlSavingsDetailRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11savings_detail_id\x18\x02 \x01(\t\"\x8a\x02\n\x13PlSavingsDetailInfo\x12\x19\n\x11savings_detail_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x11\n\tsale_type\x18\x07 \x01(\t\x12\x10\n\x08\x66or_date\x18\x08 \x01(\t\x12%\n\x04info\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\"U\n\x14PlSavingsDetailQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"l\n\x14PlSavingsDetailsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.PlSavingsDetailInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"c\n\x18PlSavingsDetailStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"<\n\x13GetPlSummaryRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nsummary_id\x18\x02 \x01(\t\"\xc6\x01\n\rPlSummaryInfo\x12\x12\n\nsummary_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x11\n\tsale_type\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12%\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\"\xe2\x01\n\x0ePlSummaryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11savings_detail_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\x11\n\tsale_type\x18\x08 \x01(\t\x12\x10\n\x08\x66or_date\x18\t \x01(\t\"a\n\x0fPlSummariesInfo\x12\x39\n\x07results\x18\x01 \x03(\x0b\x32(.spaceone.api.inventory.v1.PlSummaryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"]\n\x12PlSummaryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa5\x0b\n\x07Savings\x12\xa0\x01\n\x10get_pl_inventory\x12\x30.spaceone.api.inventory.v1.GetPlInventoryRequest\x1a*.spaceone.api.inventory.v1.PlInventoryInfo\".\x82\xd3\xe4\x93\x02(\"&/inventory/v1/savings/pl-inventory/get\x12\x9e\x01\n\x11list_pl_inventory\x12+.spaceone.api.inventory.v1.PlInventoryQuery\x1a+.spaceone.api.inventory.v1.PlInventorysInfo\"/\x82\xd3\xe4\x93\x02)\"\'/inventory/v1/savings/pl-inventory/list\x12\x8e\x01\n\x11stat_pl_inventory\x12/.spaceone.api.inventory.v1.PlInventoryStatQuery\x1a\x17.google.protobuf.Struct\"/\x82\xd3\xe4\x93\x02)\"\'/inventory/v1/savings/pl-inventory/stat\x12\xb2\x01\n\x15get_pl_savings_detail\x12\x34.spaceone.api.inventory.v1.GetPlSavingsDetailRequest\x1a..spaceone.api.inventory.v1.PlSavingsDetailInfo\"3\x82\xd3\xe4\x93\x02-\"+/inventory/v1/savings/pl-savings-detail/get\x12\xb0\x01\n\x16list_pl_savings_detail\x12/.spaceone.api.inventory.v1.PlSavingsDetailQuery\x1a/.spaceone.api.inventory.v1.PlSavingsDetailsInfo\"4\x82\xd3\xe4\x93\x02.\",/inventory/v1/savings/pl-savings-detail/list\x12\x9c\x01\n\x16stat_pl_savings_detail\x12\x33.spaceone.api.inventory.v1.PlSavingsDetailStatQuery\x1a\x17.google.protobuf.Struct\"4\x82\xd3\xe4\x93\x02.\",/inventory/v1/savings/pl-savings-detail/stat\x12\x98\x01\n\x0eget_pl_summary\x12..spaceone.api.inventory.v1.GetPlSummaryRequest\x1a(.spaceone.api.inventory.v1.PlSummaryInfo\",\x82\xd3\xe4\x93\x02&\"$/inventory/v1/savings/pl-summary/get\x12\x97\x01\n\x0flist_pl_summary\x12).spaceone.api.inventory.v1.PlSummaryQuery\x1a*.spaceone.api.inventory.v1.PlSummariesInfo\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/savings/pl-summary/list\x12\x88\x01\n\x0fstat_pl_summary\x12-.spaceone.api.inventory.v1.PlSummaryStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/savings/pl-summary/statb\x06proto3')



_GETPLINVENTORYREQUEST = DESCRIPTOR.message_types_by_name['GetPlInventoryRequest']
_PLINVENTORYINFO = DESCRIPTOR.message_types_by_name['PlInventoryInfo']
_PLINVENTORYQUERY = DESCRIPTOR.message_types_by_name['PlInventoryQuery']
_PLINVENTORYSINFO = DESCRIPTOR.message_types_by_name['PlInventorysInfo']
_PLINVENTORYSTATQUERY = DESCRIPTOR.message_types_by_name['PlInventoryStatQuery']
_GETPLSAVINGSDETAILREQUEST = DESCRIPTOR.message_types_by_name['GetPlSavingsDetailRequest']
_PLSAVINGSDETAILINFO = DESCRIPTOR.message_types_by_name['PlSavingsDetailInfo']
_PLSAVINGSDETAILQUERY = DESCRIPTOR.message_types_by_name['PlSavingsDetailQuery']
_PLSAVINGSDETAILSINFO = DESCRIPTOR.message_types_by_name['PlSavingsDetailsInfo']
_PLSAVINGSDETAILSTATQUERY = DESCRIPTOR.message_types_by_name['PlSavingsDetailStatQuery']
_GETPLSUMMARYREQUEST = DESCRIPTOR.message_types_by_name['GetPlSummaryRequest']
_PLSUMMARYINFO = DESCRIPTOR.message_types_by_name['PlSummaryInfo']
_PLSUMMARYQUERY = DESCRIPTOR.message_types_by_name['PlSummaryQuery']
_PLSUMMARIESINFO = DESCRIPTOR.message_types_by_name['PlSummariesInfo']
_PLSUMMARYSTATQUERY = DESCRIPTOR.message_types_by_name['PlSummaryStatQuery']
GetPlInventoryRequest = _reflection.GeneratedProtocolMessageType('GetPlInventoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLINVENTORYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPlInventoryRequest)
  })
_sym_db.RegisterMessage(GetPlInventoryRequest)

PlInventoryInfo = _reflection.GeneratedProtocolMessageType('PlInventoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventoryInfo)
  })
_sym_db.RegisterMessage(PlInventoryInfo)

PlInventoryQuery = _reflection.GeneratedProtocolMessageType('PlInventoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventoryQuery)
  })
_sym_db.RegisterMessage(PlInventoryQuery)

PlInventorysInfo = _reflection.GeneratedProtocolMessageType('PlInventorysInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYSINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventorysInfo)
  })
_sym_db.RegisterMessage(PlInventorysInfo)

PlInventoryStatQuery = _reflection.GeneratedProtocolMessageType('PlInventoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLINVENTORYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlInventoryStatQuery)
  })
_sym_db.RegisterMessage(PlInventoryStatQuery)

GetPlSavingsDetailRequest = _reflection.GeneratedProtocolMessageType('GetPlSavingsDetailRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLSAVINGSDETAILREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPlSavingsDetailRequest)
  })
_sym_db.RegisterMessage(GetPlSavingsDetailRequest)

PlSavingsDetailInfo = _reflection.GeneratedProtocolMessageType('PlSavingsDetailInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailInfo)
  })
_sym_db.RegisterMessage(PlSavingsDetailInfo)

PlSavingsDetailQuery = _reflection.GeneratedProtocolMessageType('PlSavingsDetailQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailQuery)
  })
_sym_db.RegisterMessage(PlSavingsDetailQuery)

PlSavingsDetailsInfo = _reflection.GeneratedProtocolMessageType('PlSavingsDetailsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILSINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailsInfo)
  })
_sym_db.RegisterMessage(PlSavingsDetailsInfo)

PlSavingsDetailStatQuery = _reflection.GeneratedProtocolMessageType('PlSavingsDetailStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSAVINGSDETAILSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSavingsDetailStatQuery)
  })
_sym_db.RegisterMessage(PlSavingsDetailStatQuery)

GetPlSummaryRequest = _reflection.GeneratedProtocolMessageType('GetPlSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPLSUMMARYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPlSummaryRequest)
  })
_sym_db.RegisterMessage(GetPlSummaryRequest)

PlSummaryInfo = _reflection.GeneratedProtocolMessageType('PlSummaryInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARYINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummaryInfo)
  })
_sym_db.RegisterMessage(PlSummaryInfo)

PlSummaryQuery = _reflection.GeneratedProtocolMessageType('PlSummaryQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummaryQuery)
  })
_sym_db.RegisterMessage(PlSummaryQuery)

PlSummariesInfo = _reflection.GeneratedProtocolMessageType('PlSummariesInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARIESINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummariesInfo)
  })
_sym_db.RegisterMessage(PlSummariesInfo)

PlSummaryStatQuery = _reflection.GeneratedProtocolMessageType('PlSummaryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLSUMMARYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PlSummaryStatQuery)
  })
_sym_db.RegisterMessage(PlSummaryStatQuery)

_SAVINGS = DESCRIPTOR.services_by_name['Savings']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAVINGS.methods_by_name['get_pl_inventory']._options = None
  _SAVINGS.methods_by_name['get_pl_inventory']._serialized_options = b'\202\323\344\223\002(\"&/inventory/v1/savings/pl-inventory/get'
  _SAVINGS.methods_by_name['list_pl_inventory']._options = None
  _SAVINGS.methods_by_name['list_pl_inventory']._serialized_options = b'\202\323\344\223\002)\"\'/inventory/v1/savings/pl-inventory/list'
  _SAVINGS.methods_by_name['stat_pl_inventory']._options = None
  _SAVINGS.methods_by_name['stat_pl_inventory']._serialized_options = b'\202\323\344\223\002)\"\'/inventory/v1/savings/pl-inventory/stat'
  _SAVINGS.methods_by_name['get_pl_savings_detail']._options = None
  _SAVINGS.methods_by_name['get_pl_savings_detail']._serialized_options = b'\202\323\344\223\002-\"+/inventory/v1/savings/pl-savings-detail/get'
  _SAVINGS.methods_by_name['list_pl_savings_detail']._options = None
  _SAVINGS.methods_by_name['list_pl_savings_detail']._serialized_options = b'\202\323\344\223\002.\",/inventory/v1/savings/pl-savings-detail/list'
  _SAVINGS.methods_by_name['stat_pl_savings_detail']._options = None
  _SAVINGS.methods_by_name['stat_pl_savings_detail']._serialized_options = b'\202\323\344\223\002.\",/inventory/v1/savings/pl-savings-detail/stat'
  _SAVINGS.methods_by_name['get_pl_summary']._options = None
  _SAVINGS.methods_by_name['get_pl_summary']._serialized_options = b'\202\323\344\223\002&\"$/inventory/v1/savings/pl-summary/get'
  _SAVINGS.methods_by_name['list_pl_summary']._options = None
  _SAVINGS.methods_by_name['list_pl_summary']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/savings/pl-summary/list'
  _SAVINGS.methods_by_name['stat_pl_summary']._options = None
  _SAVINGS.methods_by_name['stat_pl_summary']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/savings/pl-summary/stat'
  _GETPLINVENTORYREQUEST._serialized_start=193
  _GETPLINVENTORYREQUEST._serialized_end=260
  _PLINVENTORYINFO._serialized_start=263
  _PLINVENTORYINFO._serialized_end=520
  _PLINVENTORYQUERY._serialized_start=522
  _PLINVENTORYQUERY._serialized_end=603
  _PLINVENTORYSINFO._serialized_start=605
  _PLINVENTORYSINFO._serialized_end=705
  _PLINVENTORYSTATQUERY._serialized_start=707
  _PLINVENTORYSTATQUERY._serialized_end=802
  _GETPLSAVINGSDETAILREQUEST._serialized_start=804
  _GETPLSAVINGSDETAILREQUEST._serialized_end=877
  _PLSAVINGSDETAILINFO._serialized_start=880
  _PLSAVINGSDETAILINFO._serialized_end=1146
  _PLSAVINGSDETAILQUERY._serialized_start=1148
  _PLSAVINGSDETAILQUERY._serialized_end=1233
  _PLSAVINGSDETAILSINFO._serialized_start=1235
  _PLSAVINGSDETAILSINFO._serialized_end=1343
  _PLSAVINGSDETAILSTATQUERY._serialized_start=1345
  _PLSAVINGSDETAILSTATQUERY._serialized_end=1444
  _GETPLSUMMARYREQUEST._serialized_start=1446
  _GETPLSUMMARYREQUEST._serialized_end=1506
  _PLSUMMARYINFO._serialized_start=1509
  _PLSUMMARYINFO._serialized_end=1707
  _PLSUMMARYQUERY._serialized_start=1710
  _PLSUMMARYQUERY._serialized_end=1936
  _PLSUMMARIESINFO._serialized_start=1938
  _PLSUMMARIESINFO._serialized_end=2035
  _PLSUMMARYSTATQUERY._serialized_start=2037
  _PLSUMMARYSTATQUERY._serialized_end=2130
  _SAVINGS._serialized_start=2133
  _SAVINGS._serialized_end=3578
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/resource_name_meta.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5spaceone/api/provisioning/v1/resource_name_meta.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a spaceone/api/core/v1/query.proto\"\xf7\x01\n\x14ResourceNameMetaInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x62\x62r\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x15\n\rresource_type\x18\x06 \x01(\t\x12\x0c\n\x04rank\x18\x07 \x01(\t\x12\x0c\n\x04regx\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\ncreated_by\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\"q\n\x15ResourceNameMetasInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.provisioning.v1.ResourceNameMetaInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"|\n\x15ResourceNameMetaQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t2\xf4\x01\n\x10ResourceNameMeta\x12\xdf\x01\n\x17get_resource_name_metas\x12\x33.spaceone.api.provisioning.v1.ResourceNameMetaQuery\x1a\x33.spaceone.api.provisioning.v1.ResourceNameMetasInfo\"Z\x82\xd3\xe4\x93\x02T\x12#/provisioning/v1/resource_name_metaZ-\"+/provisioning/v1/resource_name_metas/searchb\x06proto3')



_RESOURCENAMEMETAINFO = DESCRIPTOR.message_types_by_name['ResourceNameMetaInfo']
_RESOURCENAMEMETASINFO = DESCRIPTOR.message_types_by_name['ResourceNameMetasInfo']
_RESOURCENAMEMETAQUERY = DESCRIPTOR.message_types_by_name['ResourceNameMetaQuery']
ResourceNameMetaInfo = _reflection.GeneratedProtocolMessageType('ResourceNameMetaInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCENAMEMETAINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_name_meta_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceNameMetaInfo)
  })
_sym_db.RegisterMessage(ResourceNameMetaInfo)

ResourceNameMetasInfo = _reflection.GeneratedProtocolMessageType('ResourceNameMetasInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCENAMEMETASINFO,
  '__module__' : 'spaceone.api.provisioning.v1.resource_name_meta_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceNameMetasInfo)
  })
_sym_db.RegisterMessage(ResourceNameMetasInfo)

ResourceNameMetaQuery = _reflection.GeneratedProtocolMessageType('ResourceNameMetaQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCENAMEMETAQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.resource_name_meta_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.ResourceNameMetaQuery)
  })
_sym_db.RegisterMessage(ResourceNameMetaQuery)

_RESOURCENAMEMETA = DESCRIPTOR.services_by_name['ResourceNameMeta']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCENAMEMETA.methods_by_name['get_resource_name_metas']._options = None
  _RESOURCENAMEMETA.methods_by_name['get_resource_name_metas']._serialized_options = b'\202\323\344\223\002T\022#/provisioning/v1/resource_name_metaZ-\"+/provisioning/v1/resource_name_metas/search'
  _RESOURCENAMEMETAINFO._serialized_start=211
  _RESOURCENAMEMETAINFO._serialized_end=458
  _RESOURCENAMEMETASINFO._serialized_start=460
  _RESOURCENAMEMETASINFO._serialized_end=573
  _RESOURCENAMEMETAQUERY._serialized_start=575
  _RESOURCENAMEMETAQUERY._serialized_end=699
  _RESOURCENAMEMETA._serialized_start=702
  _RESOURCENAMEMETA._serialized_end=946
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/unused_service_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5spaceone/api/inventory/v1/unused_service_filter.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a spaceone/api/core/v1/query.proto\"\xab\x02\n CreateUnusedServiceFilterRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\x12\x1d\n\x15required_weight_score\x18\x03 \x01(\x02\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x14\n\x0creplica_data\x18\x06 \x03(\t\x12\x13\n\x0bmatch_rules\x18\x07 \x03(\t\x12\x30\n\x0ftarget_resource\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x10target_condition\x18\t \x03(\x0b\x32*.spaceone.api.inventory.v1.TargetCondition\"\xcd\x02\n UpdateUnusedServiceFilterRequest\x12 \n\x18unused_service_filter_id\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\x12\x1d\n\x15required_weight_score\x18\x03 \x01(\x02\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x14\n\x0creplica_data\x18\x06 \x03(\t\x12\x13\n\x0bmatch_rules\x18\x07 \x03(\t\x12\x30\n\x0ftarget_resource\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x10target_condition\x18\t \x03(\x0b\x32*.spaceone.api.inventory.v1.TargetCondition\x12\r\n\x05title\x18\n \x01(\t\"T\n\x1dGetUnusedServiceFilterRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12 \n\x18unused_service_filter_id\x18\x02 \x01(\t\"Y\n\x18UnusedServiceFilterQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x94\x03\n\x17UnusedServiceFilterInfo\x12 \n\x18unused_service_filter_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x11\n\tsub_title\x18\x03 \x01(\t\x12\x1d\n\x15required_weight_score\x18\x04 \x01(\x02\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x30\n\x0ftarget_resource\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x10target_condition\x18\x08 \x03(\x0b\x32*.spaceone.api.inventory.v1.TargetCondition\x12\x14\n\x0creplica_data\x18\t \x03(\t\x12\x13\n\x0bmatch_rules\x18\n \x03(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\nupdated_by\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\"t\n\x18UnusedServiceFiltersInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x97\x01\n\x15\x43onditionCloudService\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x0e\n\x06parser\x18\x03 \x01(\t\x12\x10\n\x08operator\x18\x04 \x01(\t\x12%\n\x05value\x18\x05 \x01(\x0b\x32\x16.google.protobuf.Value\x12\x0e\n\x06weight\x18\x06 \x01(\x05\"\xe2\x01\n\x0f\x43onditionMetric\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x0e\n\x06parser\x18\x03 \x01(\t\x12\x10\n\x08operator\x18\x04 \x01(\t\x12%\n\x05value\x18\x05 \x01(\x0b\x32\x16.google.protobuf.Value\x12\x0e\n\x06weight\x18\x06 \x01(\x05\x12\x13\n\x0bmetric_name\x18\x07 \x01(\t\x12\x0e\n\x06target\x18\x08 \x01(\t\x12\x1c\n\x14\x61ggregation_function\x18\t \x01(\t\x12\x0c\n\x04\x64\x61ys\x18\n \x01(\x05\"\xb2\x01\n\x0fTargetCondition\x12\x45\n\tcondition\x18\x01 \x01(\x0b\x32\x30.spaceone.api.inventory.v1.ConditionCloudServiceH\x00\x12\x46\n\x10\x63ondition_metric\x18\x02 \x01(\x0b\x32*.spaceone.api.inventory.v1.ConditionMetricH\x00\x42\x10\n\x0e\x63ondition_type2\xfa\x03\n\x13UnusedServiceFilter\x12{\n\x06\x63reate\x12;.spaceone.api.inventory.v1.CreateUnusedServiceFilterRequest\x1a\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\"\x00\x12{\n\x06update\x12;.spaceone.api.inventory.v1.UpdateUnusedServiceFilterRequest\x1a\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\"\x00\x12u\n\x03get\x12\x38.spaceone.api.inventory.v1.GetUnusedServiceFilterRequest\x1a\x32.spaceone.api.inventory.v1.UnusedServiceFilterInfo\"\x00\x12r\n\x04list\x12\x33.spaceone.api.inventory.v1.UnusedServiceFilterQuery\x1a\x33.spaceone.api.inventory.v1.UnusedServiceFiltersInfo\"\x00\x62\x06proto3')



_CREATEUNUSEDSERVICEFILTERREQUEST = DESCRIPTOR.message_types_by_name['CreateUnusedServiceFilterRequest']
_UPDATEUNUSEDSERVICEFILTERREQUEST = DESCRIPTOR.message_types_by_name['UpdateUnusedServiceFilterRequest']
_GETUNUSEDSERVICEFILTERREQUEST = DESCRIPTOR.message_types_by_name['GetUnusedServiceFilterRequest']
_UNUSEDSERVICEFILTERQUERY = DESCRIPTOR.message_types_by_name['UnusedServiceFilterQuery']
_UNUSEDSERVICEFILTERINFO = DESCRIPTOR.message_types_by_name['UnusedServiceFilterInfo']
_UNUSEDSERVICEFILTERSINFO = DESCRIPTOR.message_types_by_name['UnusedServiceFiltersInfo']
_CONDITIONCLOUDSERVICE = DESCRIPTOR.message_types_by_name['ConditionCloudService']
_CONDITIONMETRIC = DESCRIPTOR.message_types_by_name['ConditionMetric']
_TARGETCONDITION = DESCRIPTOR.message_types_by_name['TargetCondition']
CreateUnusedServiceFilterRequest = _reflection.GeneratedProtocolMessageType('CreateUnusedServiceFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUNUSEDSERVICEFILTERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateUnusedServiceFilterRequest)
  })
_sym_db.RegisterMessage(CreateUnusedServiceFilterRequest)

UpdateUnusedServiceFilterRequest = _reflection.GeneratedProtocolMessageType('UpdateUnusedServiceFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUNUSEDSERVICEFILTERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateUnusedServiceFilterRequest)
  })
_sym_db.RegisterMessage(UpdateUnusedServiceFilterRequest)

GetUnusedServiceFilterRequest = _reflection.GeneratedProtocolMessageType('GetUnusedServiceFilterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUNUSEDSERVICEFILTERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetUnusedServiceFilterRequest)
  })
_sym_db.RegisterMessage(GetUnusedServiceFilterRequest)

UnusedServiceFilterQuery = _reflection.GeneratedProtocolMessageType('UnusedServiceFilterQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEFILTERQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceFilterQuery)
  })
_sym_db.RegisterMessage(UnusedServiceFilterQuery)

UnusedServiceFilterInfo = _reflection.GeneratedProtocolMessageType('UnusedServiceFilterInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEFILTERINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceFilterInfo)
  })
_sym_db.RegisterMessage(UnusedServiceFilterInfo)

UnusedServiceFiltersInfo = _reflection.GeneratedProtocolMessageType('UnusedServiceFiltersInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDSERVICEFILTERSINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedServiceFiltersInfo)
  })
_sym_db.RegisterMessage(UnusedServiceFiltersInfo)

ConditionCloudService = _reflection.GeneratedProtocolMessageType('ConditionCloudService', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONCLOUDSERVICE,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ConditionCloudService)
  })
_sym_db.RegisterMessage(ConditionCloudService)

ConditionMetric = _reflection.GeneratedProtocolMessageType('ConditionMetric', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONMETRIC,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ConditionMetric)
  })
_sym_db.RegisterMessage(ConditionMetric)

TargetCondition = _reflection.GeneratedProtocolMessageType('TargetCondition', (_message.Message,), {
  'DESCRIPTOR' : _TARGETCONDITION,
  '__module__' : 'spaceone.api.inventory.v1.unused_service_filter_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.TargetCondition)
  })
_sym_db.RegisterMessage(TargetCondition)

_UNUSEDSERVICEFILTER = DESCRIPTOR.services_by_name['UnusedServiceFilter']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CREATEUNUSEDSERVICEFILTERREQUEST._serialized_start=149
  _CREATEUNUSEDSERVICEFILTERREQUEST._serialized_end=448
  _UPDATEUNUSEDSERVICEFILTERREQUEST._serialized_start=451
  _UPDATEUNUSEDSERVICEFILTERREQUEST._serialized_end=784
  _GETUNUSEDSERVICEFILTERREQUEST._serialized_start=786
  _GETUNUSEDSERVICEFILTERREQUEST._serialized_end=870
  _UNUSEDSERVICEFILTERQUERY._serialized_start=872
  _UNUSEDSERVICEFILTERQUERY._serialized_end=961
  _UNUSEDSERVICEFILTERINFO._serialized_start=964
  _UNUSEDSERVICEFILTERINFO._serialized_end=1368
  _UNUSEDSERVICEFILTERSINFO._serialized_start=1370
  _UNUSEDSERVICEFILTERSINFO._serialized_end=1486
  _CONDITIONCLOUDSERVICE._serialized_start=1489
  _CONDITIONCLOUDSERVICE._serialized_end=1640
  _CONDITIONMETRIC._serialized_start=1643
  _CONDITIONMETRIC._serialized_end=1869
  _TARGETCONDITION._serialized_start=1872
  _TARGETCONDITION._serialized_end=2050
  _UNUSEDSERVICEFILTER._serialized_start=2053
  _UNUSEDSERVICEFILTER._serialized_end=2559
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/public_dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4spaceone/api/cost_analysis/v1/public_dashboard.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"3\n\x15PublicDashboardPeriod\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\"\xb6\x03\n\x1c\x43reatePublicDashboardRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x02 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12[\n\x0bperiod_type\x18\x05 \x01(\x0e\x32\x46.spaceone.api.cost_analysis.v1.CreatePublicDashboardRequest.PeriodType\x12\x44\n\x06period\x18\x06 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.PublicDashboardPeriod\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xd3\x03\n\x1cUpdatePublicDashboardRequest\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12[\n\x0bperiod_type\x18\x06 \x01(\x0e\x32\x46.spaceone.api.cost_analysis.v1.UpdatePublicDashboardRequest.PeriodType\x12\x44\n\x06period\x18\x07 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.PublicDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"H\n\x16PublicDashboardRequest\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Y\n\x19GetPublicDashboardRequest\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x82\x02\n\x14PublicDashboardQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13public_dashboard_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12S\n\x0bperiod_type\x18\x04 \x01(\x0e\x32>.spaceone.api.cost_analysis.v1.PublicDashboardQuery.PeriodType\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"\xe9\x03\n\x13PublicDashboardInfo\x12\x1b\n\x13public_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_layout_id\x18\x03 \x01(\t\x12\x32\n\x0e\x63ustom_layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12/\n\x0e\x64\x65\x66\x61ult_filter\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12R\n\x0bperiod_type\x18\x06 \x01(\x0e\x32=.spaceone.api.cost_analysis.v1.PublicDashboardInfo.PeriodType\x12\x44\n\x06period\x18\x07 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.PublicDashboardPeriod\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\"+\n\nPeriodType\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\t\n\x05\x46IXED\x10\x02\"p\n\x14PublicDashboardsInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"c\n\x18PublicDashboardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa7\x08\n\x0fPublicDashboard\x12\xa6\x01\n\x06\x63reate\x12;.spaceone.api.cost_analysis.v1.CreatePublicDashboardRequest\x1a\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\"+\x82\xd3\xe4\x93\x02%\"#/cost-analysis/v1/public-dashboards\x12\xbb\x01\n\x06update\x12;.spaceone.api.cost_analysis.v1.UpdatePublicDashboardRequest\x1a\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\"@\x82\xd3\xe4\x93\x02:\x1a\x38/cost-analysis/v1/public-dashboard/{public_dashboard_id}\x12\x99\x01\n\x06\x64\x65lete\x12\x35.spaceone.api.cost_analysis.v1.PublicDashboardRequest\x1a\x16.google.protobuf.Empty\"@\x82\xd3\xe4\x93\x02:*8/cost-analysis/v1/public-dashboard/{public_dashboard_id}\x12\xb5\x01\n\x03get\x12\x38.spaceone.api.cost_analysis.v1.GetPublicDashboardRequest\x1a\x32.spaceone.api.cost_analysis.v1.PublicDashboardInfo\"@\x82\xd3\xe4\x93\x02:\x12\x38/cost-analysis/v1/public-dashboard/{public_dashboard_id}\x12\xcb\x01\n\x04list\x12\x33.spaceone.api.cost_analysis.v1.PublicDashboardQuery\x1a\x33.spaceone.api.cost_analysis.v1.PublicDashboardsInfo\"Y\x82\xd3\xe4\x93\x02S\x12#/cost-analysis/v1/public-dashboardsZ,\"*/cost-analysis/v1/public-dashboards/search\x12\x8a\x01\n\x04stat\x12\x37.spaceone.api.cost_analysis.v1.PublicDashboardStatQuery\x1a\x17.google.protobuf.Struct\"0\x82\xd3\xe4\x93\x02*\"(/cost-analysis/v1/public-dashboards/statb\x06proto3')



_PUBLICDASHBOARDPERIOD = DESCRIPTOR.message_types_by_name['PublicDashboardPeriod']
_CREATEPUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreatePublicDashboardRequest']
_UPDATEPUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdatePublicDashboardRequest']
_PUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['PublicDashboardRequest']
_GETPUBLICDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetPublicDashboardRequest']
_PUBLICDASHBOARDQUERY = DESCRIPTOR.message_types_by_name['PublicDashboardQuery']
_PUBLICDASHBOARDINFO = DESCRIPTOR.message_types_by_name['PublicDashboardInfo']
_PUBLICDASHBOARDSINFO = DESCRIPTOR.message_types_by_name['PublicDashboardsInfo']
_PUBLICDASHBOARDSTATQUERY = DESCRIPTOR.message_types_by_name['PublicDashboardStatQuery']
_CREATEPUBLICDASHBOARDREQUEST_PERIODTYPE = _CREATEPUBLICDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_UPDATEPUBLICDASHBOARDREQUEST_PERIODTYPE = _UPDATEPUBLICDASHBOARDREQUEST.enum_types_by_name['PeriodType']
_PUBLICDASHBOARDQUERY_PERIODTYPE = _PUBLICDASHBOARDQUERY.enum_types_by_name['PeriodType']
_PUBLICDASHBOARDINFO_PERIODTYPE = _PUBLICDASHBOARDINFO.enum_types_by_name['PeriodType']
PublicDashboardPeriod = _reflection.GeneratedProtocolMessageType('PublicDashboardPeriod', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDPERIOD,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardPeriod)
  })
_sym_db.RegisterMessage(PublicDashboardPeriod)

CreatePublicDashboardRequest = _reflection.GeneratedProtocolMessageType('CreatePublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreatePublicDashboardRequest)
  })
_sym_db.RegisterMessage(CreatePublicDashboardRequest)

UpdatePublicDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdatePublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdatePublicDashboardRequest)
  })
_sym_db.RegisterMessage(UpdatePublicDashboardRequest)

PublicDashboardRequest = _reflection.GeneratedProtocolMessageType('PublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardRequest)
  })
_sym_db.RegisterMessage(PublicDashboardRequest)

GetPublicDashboardRequest = _reflection.GeneratedProtocolMessageType('GetPublicDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetPublicDashboardRequest)
  })
_sym_db.RegisterMessage(GetPublicDashboardRequest)

PublicDashboardQuery = _reflection.GeneratedProtocolMessageType('PublicDashboardQuery', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardQuery)
  })
_sym_db.RegisterMessage(PublicDashboardQuery)

PublicDashboardInfo = _reflection.GeneratedProtocolMessageType('PublicDashboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardInfo)
  })
_sym_db.RegisterMessage(PublicDashboardInfo)

PublicDashboardsInfo = _reflection.GeneratedProtocolMessageType('PublicDashboardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardsInfo)
  })
_sym_db.RegisterMessage(PublicDashboardsInfo)

PublicDashboardStatQuery = _reflection.GeneratedProtocolMessageType('PublicDashboardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICDASHBOARDSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.public_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PublicDashboardStatQuery)
  })
_sym_db.RegisterMessage(PublicDashboardStatQuery)

_PUBLICDASHBOARD = DESCRIPTOR.services_by_name['PublicDashboard']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLICDASHBOARD.methods_by_name['create']._options = None
  _PUBLICDASHBOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002%\"#/cost-analysis/v1/public-dashboards'
  _PUBLICDASHBOARD.methods_by_name['update']._options = None
  _PUBLICDASHBOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\002:\0328/cost-analysis/v1/public-dashboard/{public_dashboard_id}'
  _PUBLICDASHBOARD.methods_by_name['delete']._options = None
  _PUBLICDASHBOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002:*8/cost-analysis/v1/public-dashboard/{public_dashboard_id}'
  _PUBLICDASHBOARD.methods_by_name['get']._options = None
  _PUBLICDASHBOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\002:\0228/cost-analysis/v1/public-dashboard/{public_dashboard_id}'
  _PUBLICDASHBOARD.methods_by_name['list']._options = None
  _PUBLICDASHBOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002S\022#/cost-analysis/v1/public-dashboardsZ,\"*/cost-analysis/v1/public-dashboards/search'
  _PUBLICDASHBOARD.methods_by_name['stat']._options = None
  _PUBLICDASHBOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002*\"(/cost-analysis/v1/public-dashboards/stat'
  _PUBLICDASHBOARDPERIOD._serialized_start=210
  _PUBLICDASHBOARDPERIOD._serialized_end=261
  _CREATEPUBLICDASHBOARDREQUEST._serialized_start=264
  _CREATEPUBLICDASHBOARDREQUEST._serialized_end=702
  _CREATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_start=659
  _CREATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_end=702
  _UPDATEPUBLICDASHBOARDREQUEST._serialized_start=705
  _UPDATEPUBLICDASHBOARDREQUEST._serialized_end=1172
  _UPDATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_start=659
  _UPDATEPUBLICDASHBOARDREQUEST_PERIODTYPE._serialized_end=702
  _PUBLICDASHBOARDREQUEST._serialized_start=1174
  _PUBLICDASHBOARDREQUEST._serialized_end=1246
  _GETPUBLICDASHBOARDREQUEST._serialized_start=1248
  _GETPUBLICDASHBOARDREQUEST._serialized_end=1337
  _PUBLICDASHBOARDQUERY._serialized_start=1340
  _PUBLICDASHBOARDQUERY._serialized_end=1598
  _PUBLICDASHBOARDQUERY_PERIODTYPE._serialized_start=659
  _PUBLICDASHBOARDQUERY_PERIODTYPE._serialized_end=702
  _PUBLICDASHBOARDINFO._serialized_start=1601
  _PUBLICDASHBOARDINFO._serialized_end=2090
  _PUBLICDASHBOARDINFO_PERIODTYPE._serialized_start=659
  _PUBLICDASHBOARDINFO_PERIODTYPE._serialized_end=702
  _PUBLICDASHBOARDSINFO._serialized_start=2092
  _PUBLICDASHBOARDSINFO._serialized_end=2204
  _PUBLICDASHBOARDSTATQUERY._serialized_start=2206
  _PUBLICDASHBOARDSTATQUERY._serialized_end=2305
  _PUBLICDASHBOARD._serialized_start=2308
  _PUBLICDASHBOARD._serialized_end=3371
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/consumers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/provisioning/v1/consumers.proto\x12\x1cspaceone.api.provisioning.v12\x0b\n\tConsumersb\x06proto3')



_CONSUMERS = DESCRIPTOR.services_by_name['Consumers']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONSUMERS._serialized_start=78
  _CONSUMERS._serialized_end=89
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/maintenance_window.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3spaceone/api/monitoring/v1/maintenance_window.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xa1\x01\n\x1e\x43reateMaintenanceWindowRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08projects\x18\x02 \x03(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\t\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xc0\x01\n\x1eUpdateMaintenanceWindowRequest\x12\x1d\n\x15maintenance_window_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x10\n\x08projects\x18\x03 \x03(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\t\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"L\n\x18MaintenanceWindowRequest\x12\x1d\n\x15maintenance_window_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"]\n\x1bGetMaintenanceWindowRequest\x12\x1d\n\x15maintenance_window_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xc1\x02\n\x16MaintenanceWindowQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1d\n\x15maintenance_window_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12X\n\x05state\x18\x04 \x01(\x0e\x32I.spaceone.api.monitoring.v1.MaintenanceWindowQuery.MaintenanceWindowState\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"8\n\x16MaintenanceWindowState\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\n\n\x06\x43LOSED\x10\x02\"\x99\x03\n\x15MaintenanceWindowInfo\x12\x1d\n\x15maintenance_window_id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12W\n\x05state\x18\x03 \x01(\x0e\x32H.spaceone.api.monitoring.v1.MaintenanceWindowInfo.MaintenanceWindowState\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x05 \x01(\t\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08projects\x18\x0b \x03(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_by\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\x12\x11\n\tclosed_at\x18\x17 \x01(\t\"8\n\x16MaintenanceWindowState\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\n\n\x06\x43LOSED\x10\x02\"q\n\x16MaintenanceWindowsInfo\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32\x31.spaceone.api.monitoring.v1.MaintenanceWindowInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"e\n\x1aMaintenanceWindowStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xbe\x08\n\x11MaintenanceWindow\x12\xa3\x01\n\x06\x63reate\x12:.spaceone.api.monitoring.v1.CreateMaintenanceWindowRequest\x1a\x31.spaceone.api.monitoring.v1.MaintenanceWindowInfo\"*\x82\xd3\xe4\x93\x02$\"\"/monitoring/v1/maintenance-windows\x12\xba\x01\n\x06update\x12:.spaceone.api.monitoring.v1.UpdateMaintenanceWindowRequest\x1a\x31.spaceone.api.monitoring.v1.MaintenanceWindowInfo\"A\x82\xd3\xe4\x93\x02;\x1a\x39/monitoring/v1/maintenance-window/{maintenance_window_id}\x12\xb9\x01\n\x05\x63lose\x12\x34.spaceone.api.monitoring.v1.MaintenanceWindowRequest\x1a\x31.spaceone.api.monitoring.v1.MaintenanceWindowInfo\"G\x82\xd3\xe4\x93\x02\x41\x1a?/monitoring/v1/maintenance-window/{maintenance_window_id}/close\x12\xb4\x01\n\x03get\x12\x37.spaceone.api.monitoring.v1.GetMaintenanceWindowRequest\x1a\x31.spaceone.api.monitoring.v1.MaintenanceWindowInfo\"A\x82\xd3\xe4\x93\x02;\x12\x39/monitoring/v1/maintenance-window/{maintenance_window_id}\x12\xc7\x01\n\x04list\x12\x32.spaceone.api.monitoring.v1.MaintenanceWindowQuery\x1a\x32.spaceone.api.monitoring.v1.MaintenanceWindowsInfo\"W\x82\xd3\xe4\x93\x02Q\x12\"/monitoring/v1/maintenance-windowsZ+\")/monitoring/v1/maintenance-windows/search\x12\x88\x01\n\x04stat\x12\x36.spaceone.api.monitoring.v1.MaintenanceWindowStatQuery\x1a\x17.google.protobuf.Struct\"/\x82\xd3\xe4\x93\x02)\"\'/monitoring/v1/maintenance-windows/statb\x06proto3')



_CREATEMAINTENANCEWINDOWREQUEST = DESCRIPTOR.message_types_by_name['CreateMaintenanceWindowRequest']
_UPDATEMAINTENANCEWINDOWREQUEST = DESCRIPTOR.message_types_by_name['UpdateMaintenanceWindowRequest']
_MAINTENANCEWINDOWREQUEST = DESCRIPTOR.message_types_by_name['MaintenanceWindowRequest']
_GETMAINTENANCEWINDOWREQUEST = DESCRIPTOR.message_types_by_name['GetMaintenanceWindowRequest']
_MAINTENANCEWINDOWQUERY = DESCRIPTOR.message_types_by_name['MaintenanceWindowQuery']
_MAINTENANCEWINDOWINFO = DESCRIPTOR.message_types_by_name['MaintenanceWindowInfo']
_MAINTENANCEWINDOWSINFO = DESCRIPTOR.message_types_by_name['MaintenanceWindowsInfo']
_MAINTENANCEWINDOWSTATQUERY = DESCRIPTOR.message_types_by_name['MaintenanceWindowStatQuery']
_MAINTENANCEWINDOWQUERY_MAINTENANCEWINDOWSTATE = _MAINTENANCEWINDOWQUERY.enum_types_by_name['MaintenanceWindowState']
_MAINTENANCEWINDOWINFO_MAINTENANCEWINDOWSTATE = _MAINTENANCEWINDOWINFO.enum_types_by_name['MaintenanceWindowState']
CreateMaintenanceWindowRequest = _reflection.GeneratedProtocolMessageType('CreateMaintenanceWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMAINTENANCEWINDOWREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateMaintenanceWindowRequest)
  })
_sym_db.RegisterMessage(CreateMaintenanceWindowRequest)

UpdateMaintenanceWindowRequest = _reflection.GeneratedProtocolMessageType('UpdateMaintenanceWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMAINTENANCEWINDOWREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateMaintenanceWindowRequest)
  })
_sym_db.RegisterMessage(UpdateMaintenanceWindowRequest)

MaintenanceWindowRequest = _reflection.GeneratedProtocolMessageType('MaintenanceWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEWINDOWREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MaintenanceWindowRequest)
  })
_sym_db.RegisterMessage(MaintenanceWindowRequest)

GetMaintenanceWindowRequest = _reflection.GeneratedProtocolMessageType('GetMaintenanceWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMAINTENANCEWINDOWREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetMaintenanceWindowRequest)
  })
_sym_db.RegisterMessage(GetMaintenanceWindowRequest)

MaintenanceWindowQuery = _reflection.GeneratedProtocolMessageType('MaintenanceWindowQuery', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEWINDOWQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MaintenanceWindowQuery)
  })
_sym_db.RegisterMessage(MaintenanceWindowQuery)

MaintenanceWindowInfo = _reflection.GeneratedProtocolMessageType('MaintenanceWindowInfo', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEWINDOWINFO,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MaintenanceWindowInfo)
  })
_sym_db.RegisterMessage(MaintenanceWindowInfo)

MaintenanceWindowsInfo = _reflection.GeneratedProtocolMessageType('MaintenanceWindowsInfo', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEWINDOWSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MaintenanceWindowsInfo)
  })
_sym_db.RegisterMessage(MaintenanceWindowsInfo)

MaintenanceWindowStatQuery = _reflection.GeneratedProtocolMessageType('MaintenanceWindowStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _MAINTENANCEWINDOWSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.maintenance_window_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MaintenanceWindowStatQuery)
  })
_sym_db.RegisterMessage(MaintenanceWindowStatQuery)

_MAINTENANCEWINDOW = DESCRIPTOR.services_by_name['MaintenanceWindow']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MAINTENANCEWINDOW.methods_by_name['create']._options = None
  _MAINTENANCEWINDOW.methods_by_name['create']._serialized_options = b'\202\323\344\223\002$\"\"/monitoring/v1/maintenance-windows'
  _MAINTENANCEWINDOW.methods_by_name['update']._options = None
  _MAINTENANCEWINDOW.methods_by_name['update']._serialized_options = b'\202\323\344\223\002;\0329/monitoring/v1/maintenance-window/{maintenance_window_id}'
  _MAINTENANCEWINDOW.methods_by_name['close']._options = None
  _MAINTENANCEWINDOW.methods_by_name['close']._serialized_options = b'\202\323\344\223\002A\032?/monitoring/v1/maintenance-window/{maintenance_window_id}/close'
  _MAINTENANCEWINDOW.methods_by_name['get']._options = None
  _MAINTENANCEWINDOW.methods_by_name['get']._serialized_options = b'\202\323\344\223\002;\0229/monitoring/v1/maintenance-window/{maintenance_window_id}'
  _MAINTENANCEWINDOW.methods_by_name['list']._options = None
  _MAINTENANCEWINDOW.methods_by_name['list']._serialized_options = b'\202\323\344\223\002Q\022\"/monitoring/v1/maintenance-windowsZ+\")/monitoring/v1/maintenance-windows/search'
  _MAINTENANCEWINDOW.methods_by_name['stat']._options = None
  _MAINTENANCEWINDOW.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002)\"\'/monitoring/v1/maintenance-windows/stat'
  _CREATEMAINTENANCEWINDOWREQUEST._serialized_start=178
  _CREATEMAINTENANCEWINDOWREQUEST._serialized_end=339
  _UPDATEMAINTENANCEWINDOWREQUEST._serialized_start=342
  _UPDATEMAINTENANCEWINDOWREQUEST._serialized_end=534
  _MAINTENANCEWINDOWREQUEST._serialized_start=536
  _MAINTENANCEWINDOWREQUEST._serialized_end=612
  _GETMAINTENANCEWINDOWREQUEST._serialized_start=614
  _GETMAINTENANCEWINDOWREQUEST._serialized_end=707
  _MAINTENANCEWINDOWQUERY._serialized_start=710
  _MAINTENANCEWINDOWQUERY._serialized_end=1031
  _MAINTENANCEWINDOWQUERY_MAINTENANCEWINDOWSTATE._serialized_start=975
  _MAINTENANCEWINDOWQUERY_MAINTENANCEWINDOWSTATE._serialized_end=1031
  _MAINTENANCEWINDOWINFO._serialized_start=1034
  _MAINTENANCEWINDOWINFO._serialized_end=1443
  _MAINTENANCEWINDOWINFO_MAINTENANCEWINDOWSTATE._serialized_start=975
  _MAINTENANCEWINDOWINFO_MAINTENANCEWINDOWSTATE._serialized_end=1031
  _MAINTENANCEWINDOWSINFO._serialized_start=1445
  _MAINTENANCEWINDOWSINFO._serialized_end=1558
  _MAINTENANCEWINDOWSTATQUERY._serialized_start=1560
  _MAINTENANCEWINDOWSTATQUERY._serialized_end=1661
  _MAINTENANCEWINDOW._serialized_start=1664
  _MAINTENANCEWINDOW._serialized_end=2750
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/savings_recommendation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6spaceone/api/inventory/v1/savings_recommendation.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"O\n\x1fGetSavingsRecommendationRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11recommendation_id\x18\x02 \x01(\t\"\xd6\x04\n\x19SavingsRecommendationInfo\x12\x19\n\x11recommendation_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x1b\n\x13recommendation_type\x18\x07 \x01(\t\x12\x0f\n\x07service\x18\x08 \x01(\t\x12\x15\n\rinstance_type\x18\t \x01(\t\x12\x1c\n\x14\x61nalysis_period_code\x18\n \x01(\t\x12\x1c\n\x14\x61nalysis_period_name\x18\x0b \x01(\t\x12\x17\n\x0fpurchase_period\x18\x0c \x01(\t\x12\x16\n\x0epayment_option\x18\r \x01(\t\x12\x1c\n\x14recommended_quantity\x18\x0e \x01(\x05\x12\x13\n\x0b\x66lexibility\x18\x0f \x01(\t\x12\x0e\n\x06region\x18\x10 \x01(\t\x12\x10\n\x08platform\x18\x11 \x01(\t\x12\x1a\n\x12savings_percentage\x18\x12 \x01(\x01\x12\x1b\n\x13month_ondemand_cost\x18\x13 \x01(\x01\x12\x1a\n\x12month_savings_cost\x18\x14 \x01(\x01\x12\x34\n\x13recommendation_info\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x16 \x01(\t\x12\x12\n\nupdated_at\x18\x17 \x01(\t\"\xba\x01\n\x1aSavingsRecommendationQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x1b\n\x13recommendation_type\x18\x06 \x01(\t\"x\n\x1aSavingsRecommendationsInfo\x12\x45\n\x07results\x18\x01 \x03(\x0b\x32\x34.spaceone.api.inventory.v1.SavingsRecommendationInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"i\n\x1eSavingsRecommendationStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xfd\x03\n\x15SavingsRecommendation\x12\xa9\x01\n\x03get\x12:.spaceone.api.inventory.v1.GetSavingsRecommendationRequest\x1a\x34.spaceone.api.inventory.v1.SavingsRecommendationInfo\"0\x82\xd3\xe4\x93\x02*\"(/inventory/v1/savings-recommendation/get\x12\xa7\x01\n\x04list\x12\x35.spaceone.api.inventory.v1.SavingsRecommendationQuery\x1a\x35.spaceone.api.inventory.v1.SavingsRecommendationsInfo\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/savings-recommendation/list\x12\x8d\x01\n\x04stat\x12\x39.spaceone.api.inventory.v1.SavingsRecommendationStatQuery\x1a\x17.google.protobuf.Struct\"1\x82\xd3\xe4\x93\x02+\")/inventory/v1/savings-recommendation/statb\x06proto3')



_GETSAVINGSRECOMMENDATIONREQUEST = DESCRIPTOR.message_types_by_name['GetSavingsRecommendationRequest']
_SAVINGSRECOMMENDATIONINFO = DESCRIPTOR.message_types_by_name['SavingsRecommendationInfo']
_SAVINGSRECOMMENDATIONQUERY = DESCRIPTOR.message_types_by_name['SavingsRecommendationQuery']
_SAVINGSRECOMMENDATIONSINFO = DESCRIPTOR.message_types_by_name['SavingsRecommendationsInfo']
_SAVINGSRECOMMENDATIONSTATQUERY = DESCRIPTOR.message_types_by_name['SavingsRecommendationStatQuery']
GetSavingsRecommendationRequest = _reflection.GeneratedProtocolMessageType('GetSavingsRecommendationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSAVINGSRECOMMENDATIONREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetSavingsRecommendationRequest)
  })
_sym_db.RegisterMessage(GetSavingsRecommendationRequest)

SavingsRecommendationInfo = _reflection.GeneratedProtocolMessageType('SavingsRecommendationInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationInfo)
  })
_sym_db.RegisterMessage(SavingsRecommendationInfo)

SavingsRecommendationQuery = _reflection.GeneratedProtocolMessageType('SavingsRecommendationQuery', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationQuery)
  })
_sym_db.RegisterMessage(SavingsRecommendationQuery)

SavingsRecommendationsInfo = _reflection.GeneratedProtocolMessageType('SavingsRecommendationsInfo', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONSINFO,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationsInfo)
  })
_sym_db.RegisterMessage(SavingsRecommendationsInfo)

SavingsRecommendationStatQuery = _reflection.GeneratedProtocolMessageType('SavingsRecommendationStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SAVINGSRECOMMENDATIONSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.savings_recommendation_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.SavingsRecommendationStatQuery)
  })
_sym_db.RegisterMessage(SavingsRecommendationStatQuery)

_SAVINGSRECOMMENDATION = DESCRIPTOR.services_by_name['SavingsRecommendation']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['get']._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['get']._serialized_options = b'\202\323\344\223\002*\"(/inventory/v1/savings-recommendation/get'
  _SAVINGSRECOMMENDATION.methods_by_name['list']._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['list']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/savings-recommendation/list'
  _SAVINGSRECOMMENDATION.methods_by_name['stat']._options = None
  _SAVINGSRECOMMENDATION.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002+\")/inventory/v1/savings-recommendation/stat'
  _GETSAVINGSRECOMMENDATIONREQUEST._serialized_start=179
  _GETSAVINGSRECOMMENDATIONREQUEST._serialized_end=258
  _SAVINGSRECOMMENDATIONINFO._serialized_start=261
  _SAVINGSRECOMMENDATIONINFO._serialized_end=859
  _SAVINGSRECOMMENDATIONQUERY._serialized_start=862
  _SAVINGSRECOMMENDATIONQUERY._serialized_end=1048
  _SAVINGSRECOMMENDATIONSINFO._serialized_start=1050
  _SAVINGSRECOMMENDATIONSINFO._serialized_end=1170
  _SAVINGSRECOMMENDATIONSTATQUERY._serialized_start=1172
  _SAVINGSRECOMMENDATIONSTATQUERY._serialized_end=1277
  _SAVINGSRECOMMENDATION._serialized_start=1280
  _SAVINGSRECOMMENDATION._serialized_end=1789
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/server.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/inventory/v1/server.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"=\n\x0fServerReference\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rexternal_link\x18\x02 \x01(\t\"\xbe\x01\n\tServerNIC\x12\x14\n\x0c\x64\x65vice_index\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x10\n\x08nic_type\x18\x03 \x01(\t\x12\x14\n\x0cip_addresses\x18\x04 \x03(\t\x12\x0c\n\x04\x63idr\x18\x05 \x01(\t\x12\x13\n\x0bmac_address\x18\x06 \x01(\t\x12\x19\n\x11public_ip_address\x18\x07 \x01(\t\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\"z\n\nServerDisk\x12\x14\n\x0c\x64\x65vice_index\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x11\n\tdisk_type\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x02\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xdf\x04\n\x13\x43reateServerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x12primary_ip_address\x18\x02 \x01(\t\x12\x38\n\x07os_type\x18\x03 \x01(\x0e\x32\'.spaceone.api.inventory.v1.ServerOSType\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x15\n\rinstance_type\x18\x05 \x01(\t\x12\x13\n\x0blaunched_at\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\t \x01(\t\x12\x13\n\x0bregion_code\x18\n \x01(\t\x12%\n\x04\x64\x61ta\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x04nics\x18\x17 \x03(\x0b\x32$.spaceone.api.inventory.v1.ServerNIC\x12\x34\n\x05\x64isks\x18\x18 \x03(\x0b\x32%.spaceone.api.inventory.v1.ServerDisk\x12=\n\treference\x18\x19 \x01(\x0b\x32*.spaceone.api.inventory.v1.ServerReference\x12%\n\x04tags\x18\x1a \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x1f \x01(\t\x12\x11\n\tdomain_id\x18  \x01(\t\"\xa3\x05\n\x13UpdateServerRequest\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12primary_ip_address\x18\x03 \x01(\t\x12\x38\n\x07os_type\x18\x04 \x01(\x0e\x32\'.spaceone.api.inventory.v1.ServerOSType\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x13\n\x0blaunched_at\x18\x07 \x01(\t\x12\x10\n\x08provider\x18\x08 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\t \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\n \x01(\t\x12\x13\n\x0bregion_code\x18\x0b \x01(\t\x12%\n\x04\x64\x61ta\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x04nics\x18\x17 \x03(\x0b\x32$.spaceone.api.inventory.v1.ServerNIC\x12\x34\n\x05\x64isks\x18\x18 \x03(\x0b\x32%.spaceone.api.inventory.v1.ServerDisk\x12=\n\treference\x18\x19 \x01(\x0b\x32*.spaceone.api.inventory.v1.ServerReference\x12%\n\x04tags\x18\x1a \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x1f \x01(\t\x12\x11\n\tdomain_id\x18  \x01(\t\x12\x16\n\x0erelease_region\x18! \x01(\x08\x12\x17\n\x0frelease_project\x18\" \x01(\x08\"J\n\x14PinServerDataRequest\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"5\n\rServerRequest\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x10GetServerRequest\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb9\x03\n\x0bServerQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tserver_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x1a\n\x12primary_ip_address\x18\x05 \x01(\t\x12\x14\n\x0cip_addresses\x18\x06 \x01(\t\x12\x38\n\x07os_type\x18\x07 \x01(\x0e\x32\'.spaceone.api.inventory.v1.ServerOSType\x12\x0f\n\x07\x61\x63\x63ount\x18\x08 \x01(\t\x12\x15\n\rinstance_type\x18\t \x01(\t\x12\x10\n\x08provider\x18\n \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x0b \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x0c \x01(\t\x12\x13\n\x0bregion_code\x18\r \x01(\t\x12\x19\n\x11resource_group_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x18\n\x10project_group_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\"\xfc\x05\n\nServerInfo\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x1a\n\x12primary_ip_address\x18\x04 \x01(\t\x12\x14\n\x0cip_addresses\x18\x05 \x03(\t\x12\x38\n\x07os_type\x18\x06 \x01(\x0e\x32\'.spaceone.api.inventory.v1.ServerOSType\x12\x0f\n\x07\x61\x63\x63ount\x18\x07 \x01(\t\x12\x15\n\rinstance_type\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\n \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x0b \x01(\t\x12\x13\n\x0bregion_code\x18\x0c \x01(\t\x12%\n\x04\x64\x61ta\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x04nics\x18\x17 \x03(\x0b\x32$.spaceone.api.inventory.v1.ServerNIC\x12\x34\n\x05\x64isks\x18\x18 \x03(\x0b\x32%.spaceone.api.inventory.v1.ServerDisk\x12=\n\treference\x18\x19 \x01(\x0b\x32*.spaceone.api.inventory.v1.ServerReference\x12%\n\x04tags\x18\x1a \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x63ollection_info\x18\x1b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x1f \x01(\t\x12\x11\n\tdomain_id\x18  \x01(\t\x12\x12\n\ncreated_at\x18) \x01(\t\x12\x12\n\nupdated_at\x18* \x01(\t\x12\x12\n\ndeleted_at\x18+ \x01(\t\x12\x13\n\x0blaunched_at\x18, \x01(\t\"Z\n\x0bServersInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.inventory.v1.ServerInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"u\n\x0fServerStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t*8\n\x0cServerOSType\x12\x10\n\x0cOS_TYPE_NONE\x10\x00\x12\t\n\x05LINUX\x10\x01\x12\x0b\n\x07WINDOWS\x10\x02\x32\xb1\x07\n\x06Server\x12~\n\x06\x63reate\x12..spaceone.api.inventory.v1.CreateServerRequest\x1a%.spaceone.api.inventory.v1.ServerInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/inventory/v1/servers\x12\x89\x01\n\x06update\x12..spaceone.api.inventory.v1.UpdateServerRequest\x1a%.spaceone.api.inventory.v1.ServerInfo\"(\x82\xd3\xe4\x93\x02\"\x1a /inventory/v1/server/{server_id}\x12\x95\x01\n\x08pin_data\x12/.spaceone.api.inventory.v1.PinServerDataRequest\x1a%.spaceone.api.inventory.v1.ServerInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/inventory/v1/server/{server_id}/pin-data\x12t\n\x06\x64\x65lete\x12(.spaceone.api.inventory.v1.ServerRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"* /inventory/v1/server/{server_id}\x12\x83\x01\n\x03get\x12+.spaceone.api.inventory.v1.GetServerRequest\x1a%.spaceone.api.inventory.v1.ServerInfo\"(\x82\xd3\xe4\x93\x02\"\x12 /inventory/v1/server/{server_id}\x12\x95\x01\n\x04list\x12&.spaceone.api.inventory.v1.ServerQuery\x1a&.spaceone.api.inventory.v1.ServersInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/inventory/v1/serversZ\x1e\"\x1c/inventory/v1/servers/search\x12o\n\x04stat\x12*.spaceone.api.inventory.v1.ServerStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/inventory/v1/servers/statb\x06proto3')

_SERVEROSTYPE = DESCRIPTOR.enum_types_by_name['ServerOSType']
ServerOSType = enum_type_wrapper.EnumTypeWrapper(_SERVEROSTYPE)
OS_TYPE_NONE = 0
LINUX = 1
WINDOWS = 2


_SERVERREFERENCE = DESCRIPTOR.message_types_by_name['ServerReference']
_SERVERNIC = DESCRIPTOR.message_types_by_name['ServerNIC']
_SERVERDISK = DESCRIPTOR.message_types_by_name['ServerDisk']
_CREATESERVERREQUEST = DESCRIPTOR.message_types_by_name['CreateServerRequest']
_UPDATESERVERREQUEST = DESCRIPTOR.message_types_by_name['UpdateServerRequest']
_PINSERVERDATAREQUEST = DESCRIPTOR.message_types_by_name['PinServerDataRequest']
_SERVERREQUEST = DESCRIPTOR.message_types_by_name['ServerRequest']
_GETSERVERREQUEST = DESCRIPTOR.message_types_by_name['GetServerRequest']
_SERVERQUERY = DESCRIPTOR.message_types_by_name['ServerQuery']
_SERVERINFO = DESCRIPTOR.message_types_by_name['ServerInfo']
_SERVERSINFO = DESCRIPTOR.message_types_by_name['ServersInfo']
_SERVERSTATQUERY = DESCRIPTOR.message_types_by_name['ServerStatQuery']
ServerReference = _reflection.GeneratedProtocolMessageType('ServerReference', (_message.Message,), {
  'DESCRIPTOR' : _SERVERREFERENCE,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServerReference)
  })
_sym_db.RegisterMessage(ServerReference)

ServerNIC = _reflection.GeneratedProtocolMessageType('ServerNIC', (_message.Message,), {
  'DESCRIPTOR' : _SERVERNIC,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServerNIC)
  })
_sym_db.RegisterMessage(ServerNIC)

ServerDisk = _reflection.GeneratedProtocolMessageType('ServerDisk', (_message.Message,), {
  'DESCRIPTOR' : _SERVERDISK,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServerDisk)
  })
_sym_db.RegisterMessage(ServerDisk)

CreateServerRequest = _reflection.GeneratedProtocolMessageType('CreateServerRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateServerRequest)
  })
_sym_db.RegisterMessage(CreateServerRequest)

UpdateServerRequest = _reflection.GeneratedProtocolMessageType('UpdateServerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateServerRequest)
  })
_sym_db.RegisterMessage(UpdateServerRequest)

PinServerDataRequest = _reflection.GeneratedProtocolMessageType('PinServerDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINSERVERDATAREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.PinServerDataRequest)
  })
_sym_db.RegisterMessage(PinServerDataRequest)

ServerRequest = _reflection.GeneratedProtocolMessageType('ServerRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServerRequest)
  })
_sym_db.RegisterMessage(ServerRequest)

GetServerRequest = _reflection.GeneratedProtocolMessageType('GetServerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetServerRequest)
  })
_sym_db.RegisterMessage(GetServerRequest)

ServerQuery = _reflection.GeneratedProtocolMessageType('ServerQuery', (_message.Message,), {
  'DESCRIPTOR' : _SERVERQUERY,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServerQuery)
  })
_sym_db.RegisterMessage(ServerQuery)

ServerInfo = _reflection.GeneratedProtocolMessageType('ServerInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVERINFO,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServerInfo)
  })
_sym_db.RegisterMessage(ServerInfo)

ServersInfo = _reflection.GeneratedProtocolMessageType('ServersInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVERSINFO,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServersInfo)
  })
_sym_db.RegisterMessage(ServersInfo)

ServerStatQuery = _reflection.GeneratedProtocolMessageType('ServerStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SERVERSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.server_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ServerStatQuery)
  })
_sym_db.RegisterMessage(ServerStatQuery)

_SERVER = DESCRIPTOR.services_by_name['Server']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVER.methods_by_name['create']._options = None
  _SERVER.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\027\"\025/inventory/v1/servers'
  _SERVER.methods_by_name['update']._options = None
  _SERVER.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\"\032 /inventory/v1/server/{server_id}'
  _SERVER.methods_by_name['pin_data']._options = None
  _SERVER.methods_by_name['pin_data']._serialized_options = b'\202\323\344\223\002+\032)/inventory/v1/server/{server_id}/pin-data'
  _SERVER.methods_by_name['delete']._options = None
  _SERVER.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\"* /inventory/v1/server/{server_id}'
  _SERVER.methods_by_name['get']._options = None
  _SERVER.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\022 /inventory/v1/server/{server_id}'
  _SERVER.methods_by_name['list']._options = None
  _SERVER.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/inventory/v1/serversZ\036\"\034/inventory/v1/servers/search'
  _SERVER.methods_by_name['stat']._options = None
  _SERVER.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/inventory/v1/servers/stat'
  _SERVEROSTYPE._serialized_start=3485
  _SERVEROSTYPE._serialized_end=3541
  _SERVERREFERENCE._serialized_start=192
  _SERVERREFERENCE._serialized_end=253
  _SERVERNIC._serialized_start=256
  _SERVERNIC._serialized_end=446
  _SERVERDISK._serialized_start=448
  _SERVERDISK._serialized_end=570
  _CREATESERVERREQUEST._serialized_start=573
  _CREATESERVERREQUEST._serialized_end=1180
  _UPDATESERVERREQUEST._serialized_start=1183
  _UPDATESERVERREQUEST._serialized_end=1858
  _PINSERVERDATAREQUEST._serialized_start=1860
  _PINSERVERDATAREQUEST._serialized_end=1934
  _SERVERREQUEST._serialized_start=1936
  _SERVERREQUEST._serialized_end=1989
  _GETSERVERREQUEST._serialized_start=1991
  _GETSERVERREQUEST._serialized_end=2061
  _SERVERQUERY._serialized_start=2064
  _SERVERQUERY._serialized_end=2505
  _SERVERINFO._serialized_start=2508
  _SERVERINFO._serialized_end=3272
  _SERVERSINFO._serialized_start=3274
  _SERVERSINFO._serialized_end=3364
  _SERVERSTATQUERY._serialized_start=3366
  _SERVERSTATQUERY._serialized_end=3483
  _SERVER._serialized_start=3544
  _SERVER._serialized_end=4489
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/monitoring/v1/data_source.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xcc\x02\n\x14\x44\x61taSourcePluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12R\n\x0cupgrade_mode\x18\x07 \x01(\x0e\x32<.spaceone.api.monitoring.v1.DataSourcePluginInfo.UpgradeMode\x12\x13\n\tsecret_id\x18\x04 \x01(\tH\x00\x12\x12\n\x08provider\x18\x05 \x01(\tH\x00\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\x42\x0f\n\rplugin_secret\"\xaa\x01\n\x19RegisterDataSourceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x0bplugin_info\x18\x03 \x01(\x0b\x32\x30.spaceone.api.monitoring.v1.DataSourcePluginInfo\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x08 \x01(\t\"y\n\x17UpdateDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\x91\x02\n\x1dUpdateDataSourcePluginRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12[\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32\x45.spaceone.api.monitoring.v1.UpdateDataSourcePluginRequest.UpgradeMode\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\">\n\x11\x44\x61taSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"O\n\x14GetDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xdc\x01\n\x0f\x44\x61taSourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x43\n\x0fmonitoring_type\x18\x05 \x01(\x0e\x32*.spaceone.api.monitoring.v1.MonitoringType\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\xbe\x03\n\x0e\x44\x61taSourceInfo\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12?\n\x05state\x18\x03 \x01(\x0e\x32\x30.spaceone.api.monitoring.v1.DataSourceInfo.State\x12\x43\n\x0fmonitoring_type\x18\x04 \x01(\x0e\x32*.spaceone.api.monitoring.v1.MonitoringType\x12\x10\n\x08provider\x18\x05 \x01(\t\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x0bplugin_info\x18\x07 \x01(\x0b\x32\x30.spaceone.api.monitoring.v1.DataSourcePluginInfo\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\t \x01(\t\x12\x12\n\ncreated_at\x18\n \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"c\n\x0f\x44\x61taSourcesInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.monitoring.v1.DataSourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"^\n\x13\x44\x61taSourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*/\n\x0eMonitoringType\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06METRIC\x10\x01\x12\x07\n\x03LOG\x10\x02\x32\xa9\x0c\n\nDataSource\x12\x92\x01\n\x08register\x12\x35.spaceone.api.monitoring.v1.RegisterDataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/monitoring/v1/data-sources\x12\x9e\x01\n\x06update\x12\x33.spaceone.api.monitoring.v1.UpdateDataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\"3\x82\xd3\xe4\x93\x02-\x1a+/monitoring/v1/data-source/{data_source_id}\x12\x9f\x01\n\x06\x65nable\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/monitoring/v1/data-source/{data_source_id}/enable\x12\xa1\x01\n\x07\x64isable\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\";\x82\xd3\xe4\x93\x02\x35\x1a\x33/monitoring/v1/data-source/{data_source_id}/disable\x12\x88\x01\n\nderegister\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-*+/monitoring/v1/data-source/{data_source_id}\x12\xb2\x01\n\rupdate_plugin\x12\x39.spaceone.api.monitoring.v1.UpdateDataSourcePluginRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/monitoring/v1/data-source/{data_source_id}/plugin\x12\x99\x01\n\rverify_plugin\x12-.spaceone.api.monitoring.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"A\x82\xd3\xe4\x93\x02;\x1a\x39/monitoring/v1/data-source/{data_source_id}/plugin/verify\x12\x98\x01\n\x03get\x12\x30.spaceone.api.monitoring.v1.GetDataSourceRequest\x1a*.spaceone.api.monitoring.v1.DataSourceInfo\"3\x82\xd3\xe4\x93\x02-\x12+/monitoring/v1/data-source/{data_source_id}\x12\xab\x01\n\x04list\x12+.spaceone.api.monitoring.v1.DataSourceQuery\x1a+.spaceone.api.monitoring.v1.DataSourcesInfo\"I\x82\xd3\xe4\x93\x02\x43\x12\x1b/monitoring/v1/data-sourcesZ$\"\"/monitoring/v1/data-sources/search\x12z\n\x04stat\x12/.spaceone.api.monitoring.v1.DataSourceStatQuery\x1a\x17.google.protobuf.Struct\"(\x82\xd3\xe4\x93\x02\"\" /monitoring/v1/data-sources/statb\x06proto3')

_MONITORINGTYPE = DESCRIPTOR.enum_types_by_name['MonitoringType']
MonitoringType = enum_type_wrapper.EnumTypeWrapper(_MONITORINGTYPE)
NONE = 0
METRIC = 1
LOG = 2


_DATASOURCEPLUGININFO = DESCRIPTOR.message_types_by_name['DataSourcePluginInfo']
_REGISTERDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['RegisterDataSourceRequest']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest']
_UPDATEDATASOURCEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourcePluginRequest']
_DATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRequest']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRequest']
_DATASOURCEQUERY = DESCRIPTOR.message_types_by_name['DataSourceQuery']
_DATASOURCEINFO = DESCRIPTOR.message_types_by_name['DataSourceInfo']
_DATASOURCESINFO = DESCRIPTOR.message_types_by_name['DataSourcesInfo']
_DATASOURCESTATQUERY = DESCRIPTOR.message_types_by_name['DataSourceStatQuery']
_DATASOURCEPLUGININFO_UPGRADEMODE = _DATASOURCEPLUGININFO.enum_types_by_name['UpgradeMode']
_UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE = _UPDATEDATASOURCEPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_DATASOURCEINFO_STATE = _DATASOURCEINFO.enum_types_by_name['State']
DataSourcePluginInfo = _reflection.GeneratedProtocolMessageType('DataSourcePluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEPLUGININFO,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourcePluginInfo)
  })
_sym_db.RegisterMessage(DataSourcePluginInfo)

RegisterDataSourceRequest = _reflection.GeneratedProtocolMessageType('RegisterDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.RegisterDataSourceRequest)
  })
_sym_db.RegisterMessage(RegisterDataSourceRequest)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

UpdateDataSourcePluginRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourcePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEPLUGINREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateDataSourcePluginRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourcePluginRequest)

DataSourceRequest = _reflection.GeneratedProtocolMessageType('DataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceRequest)
  })
_sym_db.RegisterMessage(DataSourceRequest)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)

DataSourceQuery = _reflection.GeneratedProtocolMessageType('DataSourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceQuery)
  })
_sym_db.RegisterMessage(DataSourceQuery)

DataSourceInfo = _reflection.GeneratedProtocolMessageType('DataSourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEINFO,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceInfo)
  })
_sym_db.RegisterMessage(DataSourceInfo)

DataSourcesInfo = _reflection.GeneratedProtocolMessageType('DataSourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESINFO,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourcesInfo)
  })
_sym_db.RegisterMessage(DataSourcesInfo)

DataSourceStatQuery = _reflection.GeneratedProtocolMessageType('DataSourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.DataSourceStatQuery)
  })
_sym_db.RegisterMessage(DataSourceStatQuery)

_DATASOURCE = DESCRIPTOR.services_by_name['DataSource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATASOURCE.methods_by_name['register']._options = None
  _DATASOURCE.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\035\"\033/monitoring/v1/data-sources'
  _DATASOURCE.methods_by_name['update']._options = None
  _DATASOURCE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002-\032+/monitoring/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['enable']._options = None
  _DATASOURCE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0024\0322/monitoring/v1/data-source/{data_source_id}/enable'
  _DATASOURCE.methods_by_name['disable']._options = None
  _DATASOURCE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0025\0323/monitoring/v1/data-source/{data_source_id}/disable'
  _DATASOURCE.methods_by_name['deregister']._options = None
  _DATASOURCE.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002-*+/monitoring/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['update_plugin']._options = None
  _DATASOURCE.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0024\0322/monitoring/v1/data-source/{data_source_id}/plugin'
  _DATASOURCE.methods_by_name['verify_plugin']._options = None
  _DATASOURCE.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\002;\0329/monitoring/v1/data-source/{data_source_id}/plugin/verify'
  _DATASOURCE.methods_by_name['get']._options = None
  _DATASOURCE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002-\022+/monitoring/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['list']._options = None
  _DATASOURCE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002C\022\033/monitoring/v1/data-sourcesZ$\"\"/monitoring/v1/data-sources/search'
  _DATASOURCE.methods_by_name['stat']._options = None
  _DATASOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\"\" /monitoring/v1/data-sources/stat'
  _MONITORINGTYPE._serialized_start=2120
  _MONITORINGTYPE._serialized_end=2167
  _DATASOURCEPLUGININFO._serialized_start=200
  _DATASOURCEPLUGININFO._serialized_end=532
  _DATASOURCEPLUGININFO_UPGRADEMODE._serialized_start=470
  _DATASOURCEPLUGININFO_UPGRADEMODE._serialized_end=515
  _REGISTERDATASOURCEREQUEST._serialized_start=535
  _REGISTERDATASOURCEREQUEST._serialized_end=705
  _UPDATEDATASOURCEREQUEST._serialized_start=707
  _UPDATEDATASOURCEREQUEST._serialized_end=828
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_start=831
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_end=1104
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_start=470
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_end=515
  _DATASOURCEREQUEST._serialized_start=1106
  _DATASOURCEREQUEST._serialized_end=1168
  _GETDATASOURCEREQUEST._serialized_start=1170
  _GETDATASOURCEREQUEST._serialized_end=1249
  _DATASOURCEQUERY._serialized_start=1252
  _DATASOURCEQUERY._serialized_end=1472
  _DATASOURCEINFO._serialized_start=1475
  _DATASOURCEINFO._serialized_end=1921
  _DATASOURCEINFO_STATE._serialized_start=1877
  _DATASOURCEINFO_STATE._serialized_end=1921
  _DATASOURCESINFO._serialized_start=1923
  _DATASOURCESINFO._serialized_end=2022
  _DATASOURCESTATQUERY._serialized_start=2024
  _DATASOURCESTATQUERY._serialized_end=2118
  _DATASOURCE._serialized_start=2170
  _DATASOURCE._serialized_end=3747
# @@protoc_insertion_point(module_scope)
